# Step 3 - Create a product in the database.

The Core of the orchestrator revolves around the lifecycle management of a product. Workflows are written to transition
subscriptions to a product from one status to another.

### Exercise - Create a product and workflow migration
Create a migration with the following end result.

- Make a product named: `Username registration`.
- Make sure it has one product block
- One resource type called `user_name`
- To view the result go to [http://localhost:3000/products](http://localhost:3000/products)
- A workflow called `create_username` related to the product in the database.

[Answer](answers-step3.md)
